@@ -84,6 +84,7 @@ static bool isPlayListMime (const String & mime) {
             //!strcmp (mimestr, "video/x-msvideo") ||
             !strcmp (mimestr, "video/x-real") ||
             !strcmp (mimestr, "audio/x-scpls") ||
+            !strcmp (mimestr, "audio/x-shoutcast-stream") ||
             !strcmp (mimestr, "audio/x-pn-realaudio") ||
             !strcmp (mimestr, "audio/vnd.rn-realaudio") ||
             !strcmp (mimestr, "audio/m3u") ||
@@ -228,8 +229,12 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
     if (!line.isNull ()) {
         if (cur_elm->isPlayable ())
             cur_elm = cur_elm->mrl ()->linkNode ();
-        if (cur_elm->mrl ()->mimetype == "audio/x-scpls") {
-            bool groupfound = false;
+        bool pls_groupfound =
+            line.startsWith ("[") && line.endsWith ("]") &&
+            line.mid (1, line.length () - 2).stripWhiteSpace () == "playlist";
+        if ((pls_groupfound &&
+                    cur_elm->mrl ()->mimetype.startsWith ("audio/")) ||
+                cur_elm->mrl ()->mimetype == "audio/x-scpls") {
             int nr = -1;
             struct Entry {
                 String url, title;
@@ -237,12 +242,12 @@ KDE_NO_EXPORT bool MediaInfo::readChildDoc () {
             do {
                 line = line.stripWhiteSpace ();
                 if (!line.isEmpty ()) {
-                    if (line.startsWith (String ("[")) && line.endsWith (String ("]"))) {
-                        if (!groupfound && line.mid (1, line.length () - 2).stripWhiteSpace () == "playlist")
-                            groupfound = true;
+                    if (line.startsWith ("[") && line.endsWith ("]")) {
+                        if (line.mid (1, line.length () - 2).stripWhiteSpace () == "playlist")
+                            pls_groupfound = true;
                         else
                             break;
-                    } else if (groupfound) {
+                    } else if (pls_groupfound) {
                         int eq_pos = line.indexOf (Char ('='));
                         if (eq_pos > 0) {
                             if (line.lower ().startsWith (String ("numberofentries"))) {
