@@ -68,17 +68,6 @@ public:
     unsigned int load_tree_version;
 };
 
-
-/*class KMPLAYER_NO_EXPORT ListsSource : public KMPlayer::URLSource {
-public:
-    KDE_NO_CDTOR_EXPORT ListsSource (KMPlayer::PartBase * p)
-        : KMPlayer::URLSource (p, "lists://") {}
-    void jump (KMPlayer::NodePtr e);
-    void activate ();
-    void setDocument (KMPlayer::NodePtr doc, KMPlayer::NodePtr cur);
-    String prettyName () { return m_document->mrl ()->pretty_name; }
-};*/
-
 class KMPLAYER_NO_EXPORT Recents : public FileDocument {
 public:
     Recents (Application *a);
