@@ -1115,24 +1115,63 @@ void openFile (Application * app, const gchar * path) {
 void cb_openUrls (void *app, int argc, gchar **argv) {
 }
 
-const char * saveFile (void *p, const gchar *path) {
-    Control *ctr = (Control *)p;
-    if (!path)
-        path = (const char *) ctr->cur_url;
-    int fd = open (path, O_WRONLY | O_CREAT | O_TRUNC, 0664);
-    if (fd < 0)
-        return NULL;
-    PlayListData *pd = ctr->playlist_data;
-    String str = pd->document
-        ? pd->document->childNodes ()->length () == 1
-            ? pd->document->firstChild ()->outerXML ()
-            : pd->document->outerXML ()
-        : "";
-    ::write (fd, (const char *) str, str.length ());
-    g_print ("saved %s %d bytes\n", path, str.length ());
-    ::close (fd);
-    ctr->cur_url = path;
-    return (const char *) ctr->cur_url;
+static String makeM3u (Node *n, const String &group, const String &fn) {
+    String str;
+    if (id_node_playlist_item == n->id || id_node_recent_node == n->id) {
+        if (!n->mrl ()->src.isEmpty () && fn != n->mrl ()->src) {
+            if (!n->caption ().isEmpty ())
+                str = String ("#EXTINF:,") +
+                    (id_node_playlist_item == n->id && !group.isEmpty ()
+                     ? group + " - "
+                     : String ()) +
+                    n->caption () + String ("\r\n");
+            str += n->mrl ()->src + String ("\r\n");
+        }
+    } else {
+        for (Node *c = n->firstChild (); c; c = c->nextSibling ())
+            str += makeM3u (c,
+                    id_node_group_node == n->id ? n->caption() : String (),
+                    fn);
+    }
+    return str;
+}
+
+void saveFile (Application *app, bool xml) {
+    Control *ctr = CONTROL(app);
+    String msg;
+    if (ctr->current_selected) {
+        Document *doc = ctr->current_selected->document ();
+        gchar *filename = app_file_chooser (app, app->save_folder,
+                GTK_FILE_CHOOSER_ACTION_SAVE);
+        if (filename) {
+            String fn (filename);
+            String str;
+            if (xml) {
+                if (!fn.lower ().endsWith (".xml"))
+                    fn += ".xml";
+                str = doc->outerXML ();
+            } else {
+                if (!fn.lower ().endsWith (".m3u"))
+                    fn += ".m3u";
+                str = String ("#EXTM3U\r\n") + makeM3u (doc, String (), fn);
+            }
+            int fd = open ((const char*)fn, O_WRONLY | O_CREAT | O_TRUNC, 0664);
+            if (fd < 0) {
+                msg = String( "Failed creating ") + fn + Char ('\n') + strerror (errno);
+            } else {
+                const char *txt = (const char *) str;
+                ::write (fd, txt, strlen (txt));
+                msg = String ("Saved ") + fn;
+                ::close (fd);
+            }
+            app_store_save_directory (app, filename); // free's filename
+        }
+    } else {
+        msg = "No list selected";
+    }
+    if (!msg.isEmpty ())
+        hildon_banner_show_information (GTK_WIDGET (app->window), NULL,
+                (const char *)msg);
 }
 
 void newFile (Application * app) {
