@@ -1435,7 +1435,7 @@ bool DocumentBuilder::startTag(const String &tag, AttributeListPtr attr) {
         m_ignore_depth++;
         //kdDebug () << "Warning: ignored tag " << tag.latin1 () << " ignore depth = " << m_ignore_depth << endl;
     } else {
-        NodePtr n = m_node->childFromTag (tag);
+        NodePtr n = m_node ? m_node->childFromTag (tag) : NULL;
         if (!n) {
             //kdDebug () << "Warning: unknown tag " << tag.latin1 () << endl;
             NodePtr doc = m_root->document ();
