@@ -16,6 +16,7 @@ using namespace KMPlayer;
 
 static GdkPixbuf *folder_pix;
 static GdkPixbuf *auxiliary_pix;
+static GdkPixbuf *auxiliary_fld_pix;
 static GdkPixbuf *unknown_pix;
 static GdkPixbuf *config_pix;
 static GdkPixbuf *music_pix;
@@ -80,6 +81,8 @@ enum {
 };
 
 static GdkPixbuf *iconForNode (Node *n, int child_count) {
+    if (n->auxiliaryNode ())
+        return child_count > 0 ? auxiliary_fld_pix : auxiliary_pix;
     return n->isPlayable()
         ? n->mrl ()->resolved
             ? n->mrl ()->linkNode ()->audio_only
@@ -87,9 +90,7 @@ static GdkPixbuf *iconForNode (Node *n, int child_count) {
                 : video_pix
             : video_link_pix
         : child_count > 0
-            ? n->auxiliaryNode ()
-                ? auxiliary_pix
-                : folder_pix
+            ? folder_pix
             : unknown_pix;
 }
 
@@ -660,6 +661,8 @@ GtkWidget * createTreeView (Application * app) {
     folder_pix = gtk_icon_theme_load_icon (icon_theme,
             "qgn_list_filesys_video_fldr", 26, (GtkIconLookupFlags)0, 0L);
     auxiliary_pix = gtk_icon_theme_load_icon (icon_theme,
+            "qgn_list_gene_attacpap", 26, (GtkIconLookupFlags)0, 0L);
+    auxiliary_fld_pix = gtk_icon_theme_load_icon (icon_theme,
             "qgn_list_filesys_common_fldr", 26, (GtkIconLookupFlags)0, 0L);
     unknown_pix = gtk_icon_theme_load_icon (icon_theme,
             "qgn_list_gene_unknown_file", 26, (GtkIconLookupFlags)0, 0L);
