@@ -516,7 +516,6 @@ KMPLAYER_NO_EXPORT off_t GnomeVFSFile::size () {
 }
 
 KMPLAYER_NO_EXPORT off_t GnomeVFSFile::writeBlock (const char * data, off_t length) {
-    debugLog () << "writeBlock " << int (length) << endl;
     off_t len = length;
     while (len > 0) {
         GnomeVFSFileSize bytes_written;
@@ -1102,7 +1101,6 @@ void CurlGetJob::init (IOJob *job) {
     if (!global_init) {
         global_init = !curl_global_init (CURL_GLOBAL_ALL);
         easy_list = g_tree_new (easyCompare);
-        debugLog() << "global curl init: " << global_init << endl;
         con_ic_connection = con_ic_connection_new ();
         g_signal_connect (G_OBJECT (con_ic_connection), "connection-event",
                 G_CALLBACK (icConnection), NULL);
